<!-- # ![Rex Banner](./src/lhcb_rex/tools/figures/Rex_banner.png) -->
# ![Rex Banner](https://github.com/alexmarshallbristol/Rex-image/blob/master/Rex_banner.png?raw=true)

# Rex 

Rex is a

## Table of Contents
- [About](#about)
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)


## About

```Rex``` is a 

link to wiki
link to mattermost

[📖 Project Wiki](https://gitlab.cern.ch/your-repo/-/wikis/home) | [💬 Mattermost Chat](https://mattermost.cern.ch/your-channel) | [📬 Developer Email](mailto:alex.marshall@bristol.ac.uk)



## Installation for development

```shell
uv sync
uv run pip install -e .
```

### Prerequisites  
- Python 3.9 (organised automatically by ```uv```)

Install with ```uv``` (recomended):
```shell
uv add lhcb-rex
```

Install with ```pip```:
```shell
pip install lhcb-rex
```


## Usage

Examples below

<details>
    <summary>Click to see an example</summary>

```python
def simulate():
    print("Running Rex for LHCb!")

simulate()
```

</details>


## Contributing

Contributions are welcome! Please see [CONTRIBUTING.md](CONTRIBUTING.md) for details.

---

📬 Have questions? Reach out at [alex.marshall@bristol.ac.uk](mailto:alex.marshall@bristol.ac.uk)



## Installation for development

```shell
uv sync
uv run pip install -e .
```



### Notes for me

```/dice/users/am13743/fast_vertex_quality/graveyard```
```/dice/users/am13743/fast_vertex_quality/checkpoints/```

Relevant tags/checkpoints:
- ```21_03_2025``` - Plotting for paper draft


```shell
rm -rf dist/
uv build
uv publish
```